seqinfo.cool: Accessing the sequence information in a cool/mcool file

Description Usage Arguments

View source: R/coolR.R

Description

Convering the chromosomes information from a HDF5 stored uni- or multi-dimentional contact matrix (cool or mcool file) into a seqinfo object

Usage

1

Arguments

file

Path to a HDF5 stored cool (uni-dimension) or mcool (multi-dimension sparse matrix). If using a multi-dimesion, the resolution of one of the dimension need to be passed to res

res

'NULL' if using a uni-dimensional cool file or the resolution of one of layer in the mcool file


dovetail-genomics/coolR documentation built on Oct. 7, 2020, 1:33 a.m.