Description Usage Arguments Value
This function reads HiC contact matrix file(s) created by the cooler application (https://github.com/mirnylab/cooler) stored in a HDF5 data storage and converts them to an InteractionSet object for all detected pair of genomic bins with the counts of reads in these bin pairs
1 | cool2IntSet(files, res = NULL, cores = detectCores())
|
files |
A character vector of paths to HDF5 stored cool (uni-dimension) or mcool (multi-dimension sparse matrix). If using a multi-dimesion, the resolution of one of the dimension need to be passed to res. |
res |
'NULL' if using a uni-dimensional cool file or the resolution of one of layer in the mcool file |
cores |
An integer for the number of parallel thread to convert the file |
An InteractionSet of all common pairs with the number of interaction for each pairs
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.