Description Usage Arguments Value
This function reads a compressed sparse row (CSR) storage scheme for a matrix created by the cooler application (https://github.com/mirnylab/cooler) stored in a HDF5 data storage. This utility can read the matrix or only specfic region of the genome eihter from one pair or a pair of region. If using a multi-dimension dataset (ie .mcool), the resolution needed need to be specified.
1 2 3 4 5 6 7 8 9 10 |
file |
Path to a HDF5 stored cool (uni-dimension) or mcool (multi-dimension sparse matrix). If using a multi-dimesion, the resolution of one of the dimension need to be passed to res |
res |
'NULL' if using a uni-dimensional cool file or the resolution of one of layer in the mcool file |
chr1 |
'NULL' or the chromosome name of the first pairs to return |
start1 |
'NULL' or the start of a region within chr1 to return the pairs from. If chr1 is set and start1 is NULL this will be set to 1 by default |
end1 |
'NULL' or the end of a region within chr1 to return the pairs from. If chr1 is set and end1 is NULL this will be set to the lenght of chr1 by default |
chr2 |
'NULL' or the chromosome name of the first pairs to return |
start2 |
'NULL' or the start of a region within chr2 to return the pairs from. If chr1 is set and start1 is NULL this will be set to 1 by default |
end2 |
'NULL' or the end of a region within chr1 to return the pairs from. If chr2 is set and end1 is NULL this will be set to the lenght of chr2 by default |
A GInteraction object of the contact matrix dataset
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.