Convering the chromosomes information from a HDF5 stored uni- or multi-dimentional contact matrix (cool or mcool file) into a seqinfo object
1 | seqinfo.cool(file, res = NULL)
|
file |
Path to a HDF5 stored cool (uni-dimension) or mcool (multi-dimension sparse matrix). If using a multi-dimesion, the resolution of one of the dimension need to be passed to res |
res |
'NULL' if using a uni-dimensional cool file or the resolution of one of layer in the mcool file |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.